function out = lab1_sys1(in)

%function out = lab1_sys1(in)
%
% LAB1_SYS1  --  Corrupts a signal with additive noise
%
% Input parameters:
%   in   -- the signal to be corrupted
%
% Output parameters:
%   out  -- the corrupted signal

% Written by Mark Bartsch, Winter 2002
% Modification History:
%    8/16/02  --  Added modification history (MB)



out = in + randn(size(in))*.2;
